| Title: | Deductive Rational Method |
|---|---|
| Description: | Apply the Deductive Rational Method to a monthly series of flow or precipitation data to fill in missing data. The method is as described in: Campos, D.F., (1984, ISBN:9686194444). |
| Authors: | Alonso Arriagada [aut, cre] |
| Maintainer: | Alonso Arriagada <[email protected]> |
| License: | GPL-3 |
| Version: | 1.2.0 |
| Built: | 2026-05-20 00:07:48 UTC |
| Source: | https://github.com/alobondo/deductiver |
A dataset containing dates and monthly flow values.
datadata
A data frame with 480 rows and 5 variables:
dates
years
months
days
flows, in cubic meters per second
Apply the Deductive Rational Method to a monthly series of flow or precipitation data to fill in missing data.
DR(data, negative = FALSE)DR(data, negative = FALSE)
data |
data frame with columns: date - year - month - day - station (Type date and numeric the rest) |
negative |
logical, if TRUE, negative values will be set to zero in the final result. Default is FALSE. |
BoxPlot from the result from the application of the Deductive Rational Method
DR_boxplot(dr)DR_boxplot(dr)
dr |
data frame from DR function |
Plot the result from the application of the Deductive Rational Method
DR_plot(dr, facet = FALSE)DR_plot(dr, facet = FALSE)
dr |
data frame from DR function |
facet |
logical, if TRUE, the plot will be faceted by year |
Statistics for the result from the application of the Deductive Rational Method
DR_stats(dr)DR_stats(dr)
dr |
data frame from DR function |
Seasonal Variation Curves considering results from the application of the Deductive Rational Method
DR_SVC(dr)DR_SVC(dr)
dr |
data frame from DR function |
Plot raw and infilled monthly time series
DR_timeseries_plot(raw_data, infilled_data)DR_timeseries_plot(raw_data, infilled_data)
raw_data |
data frame with columns: date - year - month - day - station (Type date and numeric the rest). Assumes station data is in the 5th column. |
infilled_data |
data frame from DR function (wide format: year, month1, month2, ...). |