Package {DeductiveR}


Type: Package
Title: Deductive Rational Method
Version: 2.0.0
Date: 2026-05-08
Description: Apply the Deductive Rational Method to a monthly series of flow or precipitation data to fill in missing data. The method is as described in: Campos, D.F., (1984, ISBN:9686194444).
License: GPL-3
LazyData: true
Encoding: UTF-8
Imports: dplyr, tidyr, ggplot2, moments, ggpubr, lmomco
Suggests: rmarkdown, knitr
VignetteBuilder: knitr
Depends: R (≥ 2.10)
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-19 21:20:31 UTC; alobo
Author: Alonso Arriagada [aut, cre]
Maintainer: Alonso Arriagada <alonso.arriagada@usach.cl>
Repository: CRAN
Date/Publication: 2026-05-19 21:30:19 UTC

Apply the Deductive Rational Method to a monthly series of flow or precipitation data to fill in missing data.

Description

Apply the Deductive Rational Method to a monthly series of flow or precipitation data to fill in missing data.

Usage

DR(data, negative = FALSE)

Arguments

data

data frame with columns: date - year - month - day - station (Type date and numeric the rest)

negative

logical, if TRUE, negative values will be set to zero in the final result. Default is FALSE.


Seasonal Variation Curves considering results from the application of the Deductive Rational Method

Description

Seasonal Variation Curves considering results from the application of the Deductive Rational Method

Usage

DR_SVC(dr)

Arguments

dr

data frame from DR function


BoxPlot from the result from the application of the Deductive Rational Method

Description

BoxPlot from the result from the application of the Deductive Rational Method

Usage

DR_boxplot(dr)

Arguments

dr

data frame from DR function


Plot the result from the application of the Deductive Rational Method

Description

Plot the result from the application of the Deductive Rational Method

Usage

DR_plot(dr, facet = FALSE)

Arguments

dr

data frame from DR function

facet

logical, if TRUE, the plot will be faceted by year


Statistics for the result from the application of the Deductive Rational Method

Description

Statistics for the result from the application of the Deductive Rational Method

Usage

DR_stats(dr)

Arguments

dr

data frame from DR function


Plot raw and infilled monthly time series

Description

Plot raw and infilled monthly time series

Usage

DR_timeseries_plot(raw_data, infilled_data)

Arguments

raw_data

data frame with columns: date - year - month - day - station (Type date and numeric the rest). Assumes station data is in the 5th column.

infilled_data

data frame from DR function (wide format: year, month1, month2, ...).


Monthly flow data from Estero Culebron DGA station

Description

A dataset containing dates and monthly flow values.

Usage

data

Format

A data frame with 480 rows and 5 variables:

date

dates

year

years

month

months

day

days

4400001

flows, in cubic meters per second

https://camels.cr2.cl/